%define         Werror_cflags      %nil

Summary:        The BOINC client core
Name:           boinc-client
Version:        7.2.42
Release:        %mkrel 9
License:        LGPLv2+
Group:          Sciences/Other
URL:            http://boinc.berkeley.edu/
# The source for this package was pulled from upstream's vcs. Use the
# following commands to generate the tarball:
# git clone git://boinc.berkeley.edu/boinc-v2.git boinc
# pushd boinc
# git checkout client_release/7.2/#{version}
# ../trim . Trim all binaries and other unnecessary things.
# rm -rf .git*
# popd
# tar -cJvf boinc-%%{version}.tar.xz boinc
# Full changelog: http://boinc.berkeley.edu/dev/forum_thread.php?id=8378
Source0:        boinc-%{version}.tar.xz
Source1:        boinc-client.service
Source2:        boinc-client-tmpfiles.conf
Source3:        boinc-manager.desktop
Source4:        trim
# Wrapper to fix GPU detection (fedora)
Source5:        boinc_gpu
Source6:        boinc-client.logrotate
# Create password file rw for group, this enables passwordless connection
# of manager from users of the boinc group.
# This won't be probably upstreamed as it might be unsafe for common usage
# without setting proper group ownership of the password file.
Patch0:         boinc-7.2.39-guirpcauth.patch
# Backport patch from 7.3 branch to fix idle time detection (fedora)
Patch1:         boinc-7.2.39-idledetect.patch
BuildRequires:  curl-devel
BuildRequires:  wxgtku-devel
BuildRequires:  gettext
BuildRequires:  jpeg-devel
BuildRequires:  openssl-devel
BuildRequires:  docbook2x
BuildRequires:  sqlite3-devel
BuildRequires:  glut-devel
BuildRequires:  libxmu-devel
BuildRequires:  libnotify-devel
BuildRequires:  xcb-util-devel
BuildRequires:  libgtk+2.0-devel
BuildRequires:  libxscrnsaver-devel
BuildRequires:  icoutils

Requires(pre):    rpm-helper >= %{rpmhelper_required_version}
Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}


%description
The Berkeley Open Infrastructure for Network Computing (BOINC) is an open-
source software platform which supports distributed computing, primarily in
the form of "volunteer" computing and "desktop Grid" computing.  It is well
suited for problems which are often described as "trivially parallel".  BOINC
is the underlying software used by projects such as SETI@home, Einstein@Home,
ClimatePrediciton.net, the World Community Grid, and many other distributed
computing projects.
This package installs the BOINC client software, which will allow your
computer to participate in one or more BOINC projects, using your spare
computer time to search for cures for diseases, model protein folding, study
global warming, discover sources of gravitational waves, and many other types
of scientific and mathematical research.

%package -n boinc-manager
Summary:        GUI to control and monitor %{name}
Group:          Sciences/Other
Requires:       %{name} = %{version}-%{release}

%description -n boinc-manager
The BOINC Manager is a graphical monitor and control utility for the BOINC
core client. It gives a detailed overview of the state of the client it is
monitoring. The BOINC Manager has two modes of operation, the "Simple View" in
which it only displays the most important information and the "Advanced View"
in which all information and all control elements are available.

%package devel
Summary:        Development files for %{name}
Group:          Development/Other
Requires:       %{name} = %{version}-%{release}
Requires:       openssl-devel
Requires:       mysql-devel

%description devel
This package contains development files for %{name}.

%package static
Summary:        Static libraries for %{name}
Group:          Sciences/Other
Requires:       %{name}-devel = %{version}-%{release}

%description static
This package contains static libraries for %{name}.


%prep
%setup -qn boinc
%autopatch -p1

# fix utf8
iconv -f ISO88591 -t UTF8 < checkin_notes_2004 > checkin_notes_2004.utf8
touch -r checkin_notes_2004 checkin_notes_2004.utf8
mv checkin_notes_2004.utf8 checkin_notes_2004

iconv -f ISO88591 -t UTF8 < checkin_notes_2005 > checkin_notes_2005.utf8
touch -r checkin_notes_2005 checkin_notes_2005.utf8
mv checkin_notes_2005.utf8 checkin_notes_2005

iconv -f ISO88591 -t UTF8 < checkin_notes_2009 > checkin_notes_2009.utf8
touch -r checkin_notes_2009 checkin_notes_2009.utf8
mv checkin_notes_2009.utf8 checkin_notes_2009

iconv -f ISO88591 -t UTF8 < checkin_notes_2010 > checkin_notes_2010.utf8
touch -r checkin_notes_2010 checkin_notes_2010.utf8
mv checkin_notes_2010.utf8 checkin_notes_2010

iconv -f ISO88591 -t UTF8 < checkin_notes_2011 > checkin_notes_2011.utf8
touch -r checkin_notes_2011 checkin_notes_2011.utf8
mv checkin_notes_2011.utf8 checkin_notes_2011

%build
%ifarch x86_64
%global boinc_platform x86_64-pc-linux-gnu
%else
%global boinc_platform i686-pc-linux-gnu
%endif

./_autosetup

%configure2_5x  --disable-dependency-tracking \
                --disable-fcgi \
                --disable-shared \
                --disable-server \
                --enable-client \
                --enable-manager \
                --enable-unicode \
                --enable-dynamic-client-linkage \
                --with-ssl \
                --with-x \
                --with-boinc-platform=%{boinc_platform}

# Disable rpaths
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make

%install
mkdir -p %{buildroot}%{_iconsdir}/hicolor/256x256/apps
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_localstatedir}/lib/boinc
mkdir -p %{buildroot}%{_mandir}/man1

%makeinstall_std




pushd %{buildroot}%{_bindir}

# use symlink instead of hardlink
rm boinc
cat > boinc <<EOF
#!/bin/bash
# wrapper script that redirects stdout/stderr to correct log paths

# we allow multiple clients so that the client does not think there is another instance running (namely this wrapper)
%{_bindir}/boinc_client --allow_multiple_clients \$@ >> %{_localstatedir}/log/boinc.log 2> %{_localstatedir}/log/boincerr.log 
EOF
chmod a+x boinc

# remove libtool archives
rm %{buildroot}%{_libdir}/*.la

popd

# own systemd script and logrotate configuration file
rm -f %{buildroot}%{_sysconfdir}/init.d/%{name} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -p -m 0755 %{SOURCE5} %{buildroot}%{_bindir}

# create .png for app icon and install .desktop file
icotool -x -i 2 clientgui/res/BOINCGUIApp.ico -o %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/boincmgr.png
install -Dp -m 0644 %{SOURCE3} %{buildroot}%{_datadir}/applications/boinc-manager.desktop

%find_lang BOINC-Client
%find_lang BOINC-Manager

# bash-completion
install -Dp -m 0644 client/scripts/boinc.bash %{buildroot}%{_sysconfdir}/bash_completion.d/boinc-client

%pre
%_pre_useradd boinc /dev/null /bin/false
 
 
%post
%_tmpfilescreate %{name} 
%_post_service %{name}


%preun
%_preun_service %{name}

%postun
%_postun_userdel boinc



%files -f BOINC-Client.lang
%config(noreplace) %{_sysconfdir}/bash_completion.d/
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%doc COPYING COPYRIGHT checkin_notes checkin_notes_*
%{_bindir}/boinc
%{_bindir}/boinc_client
%{_bindir}/boinccmd
%{_bindir}/boinc_gpu
%{_bindir}/switcher
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf

%{_mandir}/man?/boinccmd.?.*
%{_mandir}/man?/boinc.?.*
%defattr(-,boinc,boinc,-)
%dir %{_localstatedir}/lib/boinc
%{_localstatedir}/lib/boinc/



%files -n boinc-manager -f BOINC-Manager.lang
%{_bindir}/boincmgr
%{_bindir}/boincscr
%{_datadir}/applications/boinc-manager.desktop
%{_iconsdir}/*/*/apps/boincmgr.*
%{_mandir}/man?/boincmgr.?.*

%files static
%{_libdir}/libboinc.a
%{_libdir}/libboinc_api.a
%{_libdir}/libboinc_crypt.a
%{_libdir}/libboinc_graphics2.a
%{_libdir}/libboinc_opencl.a

%files devel
%{_includedir}/boinc


%changelog
* Wed Mar 02 2016 umeabot <umeabot> 7.2.42-9.mga6
+ Revision: 983169
- Rebuild for openssl

* Sat Feb 13 2016 umeabot <umeabot> 7.2.42-8.mga6
+ Revision: 959622
- Mageia 6 Mass Rebuild

* Sat Sep 26 2015 daviddavid <daviddavid> 7.2.42-7.mga6
+ Revision: 883800
- rebuild with gcc 5.2.1

* Sat Aug 01 2015 shlomif <shlomif> 7.2.42-6.mga6
+ Revision: 860424
- Fix MGA#16293 (patch by ysoft) - .service had exec bit set.

* Wed Nov 05 2014 eatdirt <eatdirt> 7.2.42-5.mga5
+ Revision: 795667
- Fix desktop file and logrotate

* Tue Nov 04 2014 eatdirt <eatdirt> 7.2.42-4.mga5
+ Revision: 795430
- Migrating boinc-client service to systemd (mga#12129)

* Wed Oct 15 2014 umeabot <umeabot> 7.2.42-3.mga5
+ Revision: 748312
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 7.2.42-2.mga5
+ Revision: 678193
- Mageia 5 Mass Rebuild

* Mon Mar 24 2014 dams <dams> 7.2.42-1.mga5
+ Revision: 607961
- new version 7.2.42

* Fri Feb 28 2014 dams <dams> 7.2.39-1.mga5
+ Revision: 597734
- new stable version 7.2.39
- replace init.d with systemd

* Fri Oct 18 2013 umeabot <umeabot> 7.0.36-3.mga4
+ Revision: 503138
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 7.0.36-2.mga3
+ Revision: 346941
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 08 2012 dams <dams> 7.0.36-1.mga3
+ Revision: 303624
- new version 7.0.36

* Sun Aug 12 2012 dams <dams> 7.0.33-1.mga3
+ Revision: 280880
- add back the icon (in Hi-Res) for the .desktop
- new version 7.0.33
- clean specfile
- remove useless single build
- rediff patch

* Mon Aug 06 2012 shlomif <shlomif> 7.0.28-1.mga3
+ Revision: 279358
- New version 7.0.28

* Fri Dec 30 2011 supp <supp> 7.0.6-1.mga2
+ Revision: 188895
- update to 7.0.6 release

* Mon Sep 26 2011 fwang <fwang> 6.12.38-1.mga2
+ Revision: 147978
- update filelist
- disable screensaver build
- fix build with latest libnotify
- fix clientgui building
- enable manager
- add more br
- new version 6.12.38

* Fri Sep 23 2011 fwang <fwang> 6.10.58-3.mga2
+ Revision: 147014
- fix group
- br xmu
- br freeglut
- clean br
- disable static

  + ahmad <ahmad>
    - Rebuild against wxgtk2.8 with enabled catch_segvs
    - Build with wxgtku-devel for unicode support

  + stormi <stormi>
    - remove unused sources

* Thu Jun 09 2011 dams <dams> 6.10.58-1.mga2
+ Revision: 102485
- update to 6.10.58 and rediff patchs
- imported package boinc-client

